PRODUCT = {
    1: "Unleaded Petrol",
    2: "Premium Unleaded",
    4: "Diesel",
    5: "LPG",
    6: "98 RON",
    7: "B20 Diesel"
}

REGION = {
    1: "Boulder",
    2: "Broome",
    3: "Busselton (Townsite)",
    4: "Carnarvon",
    5: "Collie",
    6: "Dampier",
    7: "Esperance",
    8: "Kalgoorlie",
    9: "Karratha",
    10: "Kununurra",
    11: "Narrogin",
    12: "Northam",
    13: "Port Hedland",
    14: "South Hedland",
    15: "Albany",
    16: "Bunbury",
    17: "Geraldton",
    18: "Mandurah",
    19: "Capel",
    20: "Dardanup",
    21: "Greenough",
    22: "Harvay",
    23: "Murray",
    24: "Waroona",
    25: "Metro : North of River",
    26: "Metro : South of River",
    27: "Metro : East/Hills",
    28: "Augusta / Margaret River",
    29: "Busselton (Shire)",
    30: "Bridgetown / Greenbushes",
    31: "Donnybrook / Balingup",
    32: "Manjimup",
    33: "Cataby",
    34: "Collgardie",
    35: "Cunderdin",
    36: "Dalwallinu",
    37: "Denmark",
    38: "Derby",
    39: "Dongara",
    40: "Exmouth",
    41: "Fitzroy Crossing",
    42: "Jurien",
    43: "Kambalda",
    44: "Kellerberrin",
    45: "Kojonup",
    46: "Meekatharra",
    47: "Moora",
    48: "Mt Barker",
    49: "Newman",
    50: "Norseman",
    51: "Ravensthorpe",
    53: "Tammin",
    54: "Williams",
    55: "Wubin",
    56: "York"
}

BRAND = {
    2: "Ampol",
    3: "Better Choice",
    4: "BOC",
    5: "BP",
    6: "Caltex",
    7: "Gull",
    8: "Kleenheat",
    9: "Kwikfuel",
    10: "Liberty",
    13: "Peak",
    14: "Shell",
    15: "Independent",
    16: "Wesco",
    19: "Caltex Woolworths",
    20: "Coles Express",
    21: "Black & White",
    23: "United",
    24: "Eagle"
}

SUBURB = [
    'Albany',
    'Alexander Heights',
    'Alfred Cove',
    'Applecross',
    'Armadale',
    'Ascot',
    'Attadale',
    'Augusta',
    'Australind',
    'Balcatta',
    'Baldivis',
    'Balga',
    'Balingup',
    'Ballajura',
    'Barragup',
    'Baskerville',
    'Bassendean',
    'Bayswater',
    'Beckenham',
    'Bedfordale',
    'Beechboro',
    'Beldon',
    'Bellevue',
    'Belmont',
    'Benger',
    'Bentley',
    'Bertram',
    'Bibra Lake',
    'Bicton',
    'Binningup',
    'Boulder',
    'Bouvard',
    'Boyanup',
    'Brentwood',
    'Bridgetown',
    'Broome',
    'Brunswick Junction',
    'Bull Creek',
    'Bullsbrook',
    'Bunbury',
    'Burswood',
    'Busselton',
    'Byford',
    'Canning Vale',
    'Cannington',
    'Capel',
    'Carbunup River',
    'Carine',
    'Carlisle',
    'Carnarvon',
    'Cataby',
    'Caversham',
    'Chidlow',
    'Claremont',
    'Clarkson',
    'Cloverdale',
    'Collie',
    'Como',
    'Coolgardie',
    'Coolup',
    'Cottesloe',
    'Cowaramup',
    'Cunderdin',
    'Currambine',
    'Dalwallinu',
    'Dampier',
    'Dardanup',
    'Dawesville',
    'Denmark',
    'Derby',
    'Dianella',
    'Dongara',
    'Donnybrook',
    'Doubleview',
    'Duncraig',
    'Dunsborough',
    'Dwellingup',
    'East Fremantle',
    'East Perth',
    'East Victoria Park',
    'Eaton',
    'Edgewater',
    'Ellenbrook',
    'Erskine',
    'Esperance',
    'Exmouth',
    'Falcon',
    'Fitzroy Crossing',
    'Floreat',
    'Forrestdale',
    'Forrestfield',
    'Fremantle',
    'Gelorup',
    'Geraldton',
    'Gidgegannup',
    'Girrawheen',
    'Glen Forrest',
    'Glendalough',
    'Glenfield',
    'Gnangara',
    'Golden Bay',
    'Gosnells',
    'Gracetown',
    'Greenbushes',
    'Greenough',
    'Greenwood',
    'Guildford',
    'Gwelup',
    'Halls Head',
    'Hamilton Hill',
    'Harvey',
    'Herne Hill',
    'High Wycombe',
    'Highgate',
    'Hillarys',
    'Huntingdale',
    'Innaloo',
    'Jandakot',
    'Jolimont',
    'Joondalup',
    'Jurien Bay',
    'Kalamunda',
    'Kalgoorlie',
    'Kambalda',
    'Karawara',
    'Kardinya',
    'Karragullen',
    'Karratha',
    'Karridale',
    'Karrinyup',
    'Kellerberrin',
    'Kelmscott',
    'Kewdale',
    'Kiara',
    'Kingsley',
    'Kirup',
    'Kojonup',
    'Koondoola',
    'Kununurra',
    'Kwinana',
    'Lakelands',
    'Langford',
    'Leda',
    'Leederville',
    'Leeming',
    'Lesmurdie',
    'Lynwood',
    'Maddington',
    'Madeley',
    'Malaga',
    'Mandurah',
    'Manjimup',
    'Manning',
    'Manypeaks',
    'Margaret River',
    'Meadow Springs',
    'Meekatharra',
    'Merriwa',
    'Middle Swan',
    'Midvale',
    'Mindarie',
    'Mirrabooka',
    'Moonyoonooka',
    'Moora',
    'Morley',
    'Mosman Park',
    'Mount Barker',
    'Mt Hawthorn',
    'Mt Helena',
    'Mt Lawley',
    'Mt Pleasant',
    'Mullaloo',
    'Mundaring',
    'Mundijong',
    'Munster',
    'Murdoch',
    'Myalup',
    'Myaree',
    'Narrogin',
    'Naval Base',
    'Nedlands',
    'Neerabup',
    'Newman',
    'Nollamara',
    'Noranda',
    'Norseman',
    'North Dandalup',
    'North Fremantle',
    'North Perth',
    'Northam',
    'Northbridge',
    'Northcliffe',
    'Nowergup',
    "O'Conner",
    'Ocean Reef',
    'Osborne Park',
    'Padbury',
    'Palmyra',
    'Parmelia',
    'Pearsall',
    'Pemberton',
    'Perth',
    'Picton',
    'Pinjarra',
    'Port Hedland',
    'Port Kennedy',
    'Preston Beach',
    'Quinns Rock',
    'Ravensthorpe',
    'Redcliffe',
    'Redmond',
    'Ridgewood',
    'Riverton',
    'Rivervale',
    'Rockingham',
    'Roleystone',
    'Rosa Brook',
    'Rottnest Island',
    'Sawyers Valley',
    'Scarborough',
    'Secret Harbour',
    'Serpentine',
    'Singleton',
    'Sorrento',
    'South Fremantle',
    'South Hedland',
    'South Lake',
    'South Perth',
    'South Yunderup',
    'Southern River',
    'Spearwood',
    'Stratham Downs',
    'Stratton',
    'Subiaco',
    'Success',
    'Swan View',
    'Swanbourne',
    'Tammin',
    'The Lakes',
    'Thornlie',
    'Tuart Hill',
    'Upper Swan',
    'Vasse',
    'Victoria Park',
    'Waikiki',
    'Walpole',
    'Wangara',
    'Wanneroo',
    'Warnbro',
    'Waroona',
    'Warwick',
    'Waterloo',
    'Wattle Grove',
    'Wedgefield',
    'Wellstead',
    'Welshpool',
    'Wembley',
    'West Perth',
    'West Swan',
    'Westfield',
    'Westminster',
    'Willetton',
    'Williams',
    'Witchcliffe',
    'Woodvale',
    'Wooroloo',
    'Wubin',
    'Yanchep',
    'Yokine',
    'York',
    'Young Siding',
    'Yunderup'
]
